# canvas-lti | A Canvas LTI Integration Tool

This module provides an integration tool for Canvas LTI 1.3, facilitating the creation of Learning Tools Interoperability (LTI) applications with Canvas.

## Features

- OIDC initiation and LTI launch handling
- Express middleware setup for easy integration to existing express applications
- JWKS endpoint generation for RSA key signing

## Installation

```sh
npm install canvas-lti
```
## Basic Setup
```js
const express = require('express');
const lti = require('canvas-lti');
const app = express();

lti.config({
    oidcInitiationUrl: 'https://your.canvas.domain/api/lti/authorize_redirect',
    clientId: 'your-client-id',
    baseURL: 'http://localhost:3000/',
    launchPath: 'launch',
    ltiPath: "/lti",
});

lti.expressInstance(app);

lti.on('launch', async (req, res) => {
    res.status(200).send('Your LTI tool has been successfuly launched!');
    // Any other logic you want can be added here.
});

app.listen(3000, () => {
    console.log('Server running on port 3000');
});
```

## LTI configuration
The following items are required for this module to work correctly:
- `oidcInitiationUrl`: This is the URL of your canvas installation with `/api/lti/authorize_redirect` appended ot the end.
- `clientId`: This is the client ID of the developer key for this integration within Canvas.
- `baseURL`: The base url of your application.
- `launchPath`: The launch path of your application. Do not include the LTI path as it will be added before your launch path.
- `ltiPath`: The path for all LTI related routes within your LTI application. It can contain leading or trailing "/" or no backslashes.

## JWKS endpoint
This module automatically creates a JWKS endpoint based on the ltiPath configuration. If it needs to be accessed, it can be found at `<ltiPath>/.well-known/jwks.json`

## Documentation

[Documentation](https://linktodocumentation)

