const jose = require('node-jose');

// Initialize RSA keys
let publicKey;
let keyStoreInitialized = false;

(async () => {
    const keyStore = jose.JWK.createKeyStore();
    const rsaKey = await keyStore.generate('RSA', 2048, { alg: 'RS256', use: 'sig', kid: '709572220' });
    publicKey = rsaKey.toJSON(); // Convert the key to JSON to access 'n' and 'e' directly
    keyStoreInitialized = true;
})();

// Generate JWKS asynchronously
async function getJwks() {
    // Wait for the keyStore to be initialized
    while (!keyStoreInitialized) {
        await new Promise(resolve => setTimeout(resolve, 100)); // Wait 100ms before checking again
    }

    const jwk = {
        kty: 'RSA',
        use: 'sig',
        alg: 'RS256',
        kid: '709572220',
        n: jose.util.base64url.encode(publicKey.n),
        e: jose.util.base64url.encode(publicKey.e)
    };

    return JSON.stringify({ keys: [jwk] });
}

module.exports = { getJwks };